@@ -33,7 +33,7 @@ package Apache2::AMFWURFLFilterMemcached;
 
   use vars qw($VERSION);
   my $CommonLib = new Apache2::AMFCommonLib ();
-  $VERSION= "3.30";
+  $VERSION= "3.31";
   my %Capability;
   my %Array_fb;
   my %Array_id;
@@ -51,6 +51,7 @@ package Apache2::AMFWURFLFilterMemcached;
   $MobileArray{'hiptop'}='mobile';
   $MobileArray{'htc'}='mobile';
   $MobileArray{'ipod'}='mobile';
+  $MobileArray{'ipad'}='mobile';
   $MobileArray{'kddi'}='mobile';
   $MobileArray{'kindle'}='mobile';
   $MobileArray{'lge'}='mobile';
@@ -74,6 +75,9 @@ package Apache2::AMFWURFLFilterMemcached;
   $MobileArray{'windows ce'}='mobile';
   $MobileArray{'wireless'}='mobile';
   $MobileArray{'xv6875.1'}='mobile';
+  $MobileArray{'mini'}='mobile';
+  $MobileArray{'mobi'}='mobile';
+  $MobileArray{'SymbOS'}='mobile';
 
   $PCArray{'msie'}='msie';
   $PCArray{'msie 5'}='msie_5';
